@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 use Scalar::Util qw/reftype/;
 use Carp qw/croak/;
@@ -90,7 +90,7 @@ Blessed::Merge - Merge Blessed Refs.
 
 =head1 VERSION
 
-Version 0.09
+Version 0.10
 
 =cut
 
@@ -149,20 +149,17 @@ Setting unique_hash will only set undefined key/values in the hash.
 
 Setting unique_array will merge arrays based on order and unique value.
 
-	use JSONP;
-	use overload::x qw/n/;
-
 	my $blessed = Blessed::Merge->new({ unique_array => 1 });
+
+	my $one = JSONP->new();
 	
-	my ($one, $two, $three) = JSONP->new() x n(3);
+	$one->graft('one', '{"b":["a", "c", "e"]}');
+	$one->graft('two', '{"b":["b", "d", "f"]}');
+	$one->graft('three', '{"b":["a", "b", "c", "d"]}');
 	
-	$one->graft('{"b":["a", "c", "e"]}');
-	$two->graft('{"b":["b", "d", "f"]}');
-	$three->graft('{"b":["a", "b", "c", "d"]}');
+	my $new = $blessed->merge($one->one, $one->two, $one->three);
 	
-	my $new = $blessed->merge($one, $two, $three);
-	
-	$new->serialize;  #'["a","b","c","d","e","f"]'
+	$new->serialize;  #'{"b":["a","b","c","d","e","f"]}'
 
 =head4 blessed
 
@@ -175,12 +172,12 @@ Disable to return the non blessed ref.
 
 	my ($one, $two) = JSONP->new() x n(2);
 	
-	$one->graft('{"b":["a", "c", "e"]}');
-	$two->graft('{"b":["b", "d", "f"]}');
+	$one->graft('level', '{"b":["a", "c", "e"]}');
+	$two->graft('level', '{"b":["b", "d", "f"]}');
 	
 	my $new = $blessed->merge($one, $two);
 	
-	$new;  # ["b","d","f"]
+	$new->level->b->serialize;  # ["b","d","f"]
 
 =head4 same
 
